<?php

namespace Drupal\make\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\make\Service\MakeAsApiService;
use Symfony\Component\DependencyInjection\ContainerInterface;

class SubscribeForm extends FormBase {

  protected $makeAsApiService;

  public function __construct(MakeAsApiService $make_as_api_service) {
    $this->makeAsApiService = $make_as_api_service;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('make.api_service')
    );
  }

  public function getFormId() {
    return 'make_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $enabled_fields = \Drupal::config('make.settings')->get('enabled_fields') ?? [];

    $form['email'] = [
      '#type' => 'email',
      '#title' => $this->t('Email'),
      '#required' => TRUE,
    ];

    if (isset($enabled_fields['firstname'])) {
      $form['firstname'] = [
        '#type' => 'textfield',
        '#title' => $this->t('First Name'),
        '#required' => FALSE,
      ];
    }

    if (isset($enabled_fields['lastname'])) {
      $form['lastname'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Last Name'),
        '#required' => FALSE,
      ];
    }

    if (isset($enabled_fields['address'])) {
      $form['address'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Address'),
        '#required' => FALSE,
      ];
    }

    if (isset($enabled_fields['zip'])) {
      $form['zip'] = [
        '#type' => 'textfield',
        '#title' => $this->t('ZIP'),
        '#required' => FALSE,
      ];
    }

    if (isset($enabled_fields['city'])) {
      $form['city'] = [
        '#type' => 'textfield',
        '#title' => $this->t('City'),
        '#required' => FALSE,
      ];
    }

    if (isset($enabled_fields['phone'])) {
      $form['phone'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Phone'),
        '#required' => FALSE,
      ];
    }

    if (isset($enabled_fields['company'])) {
      $form['company'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Company'),
        '#required' => FALSE,
      ];
    }

    if (isset($enabled_fields['birthday'])) {
      $form['birthday'] = [
        '#type' => 'date',
        '#title' => $this->t('Birthday'),
        '#required' => FALSE,
      ];
    }

    if (isset($enabled_fields['tags'])) {
      $form['tags'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Tags'),
        '#description' => $this->t('Comma-separated list of tags.'),
        '#required' => FALSE,
      ];
    }

    if (isset($enabled_fields['gender'])) {
      $form['gender'] = [
        '#type' => 'textfield',
        '#title' => $this->t('Gender'),
        '#required' => FALSE,
      ];
    }

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Subscribe'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $email = $form_state->getValue('email');
    $enabled_fields = \Drupal::config('make.settings')->get('enabled_fields');
    $data = ['email' => $email];

    if (isset($enabled_fields['firstname'])) {
      $data['firstname'] = $form_state->getValue('firstname');
    }

    if (isset($enabled_fields['lastname'])) {
      $data['lastname'] = $form_state->getValue('lastname');
    }

    if (isset($enabled_fields['address'])) {
      $data['address'] = $form_state->getValue('address');
    }

    if (isset($enabled_fields['zip'])) {
      $data['zip'] = $form_state->getValue('zip');
    }

    if (isset($enabled_fields['city'])) {
      $data['city'] = $form_state->getValue('city');
    }

    if (isset($enabled_fields['phone'])) {
      $data['phone'] = $form_state->getValue('phone');
    }

    if (isset($enabled_fields['company'])) {
      $data['company'] = $form_state->getValue('company');
    }

    if (isset($enabled_fields['birthday'])) {
      $data['birthday'] = $form_state->getValue('birthday');
    }

    if (isset($enabled_fields['tags'])) {
      $data['tags'] = array_map('trim', explode(',', $form_state->getValue('tags')));
    }

    if (isset($enabled_fields['gender'])) {
      $data['gender'] = $form_state->getValue('gender');
    }

    $config = \Drupal::config('make.settings');
    $list_id = $config->get('list_id');
    $result = $this->makeAsApiService->createOrUpdateSubscriber($data, $list_id);

    if ($result) {
      $this->messenger()->addStatus($this->t('Subscription successful.'));
    } else {
      $this->messenger()->addError($this->t('Failed to subscribe.'));
    }
  }
}