<?php

namespace Drupal\make\Service;

use Drupal\Core\Config\ConfigFactoryInterface;
use GuzzleHttp\ClientInterface;
use GuzzleHttp\Exception\GuzzleException;

class MakeAsApiService {
  protected $httpClient;
  protected $configFactory;

  public function __construct(ClientInterface $http_client, ConfigFactoryInterface $config_factory) {
    $this->httpClient = $http_client;
    $this->configFactory = $config_factory;
  }

  protected function getAuthHeaders() {
    $config = $this->configFactory->get('make.settings');
    $user_id = $config->get('user_id');
    $api_key = $config->get('api_key');

    return [
      'Authorization' => 'Basic ' . base64_encode($user_id . ':' . $api_key),
    ];
  }

  public function getSubscriberLists() {
    try {
      $response = $this->httpClient->get('https://subscribers.dialogapi.no/api/public/v2/subscriberlists', [
        'headers' => $this->getAuthHeaders(),
      ]);

      return json_decode($response->getBody(), true);
    } catch (GuzzleException $e) {
      \Drupal::logger('make')->error('Failed to fetch subscriber lists: @error', ['@error' => $e->getMessage()]);
      if ($e->getCode() == 401) {
        throw new \Exception('Authentication failed. Please check your User ID and API Key.');
      }
      throw new \Exception('Failed to fetch subscriber lists. Please try again later.');
    }
  }

  public function createOrUpdateSubscriber(array $data, $listId) {
    try {
      // Construct the URL with the subscriber list ID as a query parameter.
      $url = 'https://subscribers.dialogapi.no/api/public/v2/subscribers?subscriber_list_id=' . $listId;
  
      // Make the POST request to the API.
      $response = $this->httpClient->post($url, [
        'headers' => array_merge($this->getAuthHeaders(), ['Content-Type' => 'application/json']),
        'json' => $data,
      ]);
  
      // Check if the request was successful (200 OK or 201 Created).
      return in_array($response->getStatusCode(), [200, 201]);
    } catch (GuzzleException $e) {
      \Drupal::logger('make')->error('Failed to create or update subscriber: @error', ['@error' => $e->getMessage()]);
      return false;
    }
  }
}